@@ -5,4 +5,4 @@ from codetoolkit.delimiter import Delimiter
 
 if __name__ == "__main__":
 
-    print(Delimiter.split_camel("md5sum"))
\ No newline at end of file
+    print(Delimiter.split_camel("threadpool"))
\ No newline at end of file
